@@ -24,6 +24,7 @@
 #include "cheese-widget.h"
 #include "cheese-gconf.h"
 #include "cheese-camera.h"
+#include "cheese-enum-types.h"
 
 enum
 {
@@ -35,7 +36,7 @@ enum
 enum
 {
   PROP_0,
-  PROP_WIDGET
+  PROP_STATE
 };
 
 enum
@@ -45,8 +46,6 @@ enum
   PROBLEM_PAGE = 2,
 };
 
-static guint widget_signals[LAST_SIGNAL] = {0};
-
 typedef struct
 {
   GtkWidget *spinner;
@@ -54,6 +53,8 @@ typedef struct
   GtkWidget *problem;
   CheeseGConf *gconf;
   CheeseCamera *webcam;
+  CheeseWidgetState state;
+  GError *error;
 } CheeseWidgetPrivate;
 
 #define CHEESE_WIDGET_GET_PRIVATE(o)                     \
@@ -74,8 +75,8 @@ cheese_widget_load_pixbuf (GtkWidget  *widget,
   theme = gtk_icon_theme_get_for_screen (gtk_widget_get_screen (widget));
 
   /* FIXME special case "no-webcam" and actually use the icon_name */
-  pixbuf = gtk_icon_theme_load_icon (theme, "error",
-                                     size, 0, error);
+  pixbuf = gtk_icon_theme_load_icon (theme, "dialog-error",
+                                     size, GTK_ICON_LOOKUP_USE_BUILTIN | GTK_ICON_LOOKUP_FORCE_SIZE, error);
   return pixbuf;
 }
 
@@ -92,15 +93,17 @@ cheese_widget_logo_expose (GtkWidget      *w,
   guint         s_width, s_height, d_width, d_height;
   float         ratio;
 
-  gdk_draw_rectangle (w->window, w->style->black_gc, TRUE,
-                      0, 0, w->allocation.width, w->allocation.height);
+  gtk_widget_get_allocation (w, &allocation);
+
+  gdk_draw_rectangle (gtk_widget_get_window (w),
+                      gtk_widget_get_style (w)->black_gc, TRUE,
+                      0, 0, allocation.width, allocation.height);
   icon_name = g_object_get_data (G_OBJECT (w), "icon-name");
   if (icon_name == NULL)
     return FALSE;
 
   cr = gdk_cairo_create (gtk_widget_get_window (w));
   cairo_set_source_rgb (cr, 0.0, 0.0, 0.0);
-  gtk_widget_get_allocation (w, &allocation);
   cairo_rectangle (cr, 0, 0, allocation.width, allocation.height);
 
   d_width  = allocation.width;
@@ -185,6 +188,9 @@ cheese_widget_init (CheeseWidget *widget)
   CheeseWidgetPrivate *priv = CHEESE_WIDGET_GET_PRIVATE (widget);
   GtkWidget           *box;
 
+  priv->state = CHEESE_WIDGET_STATE_NONE;
+  priv->error = NULL;
+
   /* XXX
    * remove this line if you want to debug */
   gtk_notebook_set_show_tabs (GTK_NOTEBOOK (widget), FALSE);
@@ -202,11 +208,13 @@ cheese_widget_init (CheeseWidget *widget)
 
   /* Webcam page */
   priv->screen = gtk_drawing_area_new ();
+  gtk_widget_show (priv->screen);
   gtk_notebook_append_page (GTK_NOTEBOOK (widget),
                             priv->screen, gtk_label_new ("webcam"));
 
   /* Problem page */
   priv->problem = gtk_drawing_area_new ();
+  gtk_widget_show (priv->problem);
   gtk_notebook_append_page (GTK_NOTEBOOK (widget),
                             priv->problem,
                             gtk_label_new ("got problems"));
@@ -245,14 +253,15 @@ cheese_widget_set_property (GObject *object, guint prop_id,
 
   switch (prop_id)
   {
-    case PROP_WIDGET:
-      priv->widget = GTK_WIDGET (g_value_get_object (value));
+    case PROP_STATE:
+      priv->state = g_value_get_enum (value);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
   }
 }
+#endif
 
 static void
 cheese_widget_get_property (GObject *object, guint prop_id,
@@ -264,8 +273,8 @@ cheese_widget_get_property (GObject *object, guint prop_id,
 
   switch (prop_id)
   {
-    case PROP_WIDGET:
-      g_value_set_object (value, priv->widget);
+    case PROP_STATE:
+      g_value_set_enum (value, priv->state);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -273,7 +282,6 @@ cheese_widget_get_property (GObject *object, guint prop_id,
   }
 }
 
-#endif
 #if 0
 static void
 cheese_widget_changed (CheeseWidget *self)
@@ -282,14 +290,6 @@ cheese_widget_changed (CheeseWidget *self)
 
 #endif
 
-static gboolean
-cheese_widget_emit_error_idle (CheeseWidget *widget)
-{
-  g_signal_emit (widget, widget_signals[ERROR_SIGNAL], 0,
-                 _("Camera setup failed"));
-  return FALSE;
-}
-
 void
 setup_camera (CheeseWidget *widget)
 {
@@ -301,7 +301,6 @@ setup_camera (CheeseWidget *widget)
   gdouble              contrast;
   gdouble              saturation;
   gdouble              hue;
-  GError              *error = NULL;
 
   g_object_get (priv->gconf,
                 "gconf_prop_x_resolution", &x_resolution,
@@ -315,31 +314,33 @@ setup_camera (CheeseWidget *widget)
 
   gdk_threads_enter ();
   priv->webcam = cheese_camera_new (priv->screen,
-                                    webcam_device, x_resolution,
+                                    webcam_device,
+                                    x_resolution,
                                     y_resolution);
   gdk_threads_leave ();
 
   g_free (webcam_device);
 
-  cheese_camera_setup (priv->webcam, NULL, &error);
-  if (error != NULL)
-  {
-    g_warning ("Error setting up webcam %s", error->message);
-    cheese_widget_set_problem_page (CHEESE_WIDGET (widget), "no-webcam");
-    g_idle_add ((GSourceFunc) cheese_widget_emit_error_idle, widget);
-    return;
-  }
+  cheese_camera_setup (priv->webcam, NULL, &priv->error);
 
   gdk_threads_enter ();
+
   gtk_spinner_stop (GTK_SPINNER (priv->spinner));
 
-  if (cheese_camera_get_num_camera_devices (priv->webcam) == 0)
+  if (priv->error != NULL)
   {
-    cheese_widget_set_problem_page (CHEESE_WIDGET (widget), "no-webcam");
+    priv->state = CHEESE_WIDGET_STATE_ERROR;
+    g_object_notify (G_OBJECT (widget), "state");
+    cheese_widget_set_problem_page (CHEESE_WIDGET (widget), "error");
   }
   else
   {
-    g_signal_emit (widget, widget_signals[READY_SIGNAL], 0, TRUE);
+    cheese_camera_set_balance_property (priv->webcam, "brightness", brightness);
+    cheese_camera_set_balance_property (priv->webcam, "contrast", contrast);
+    cheese_camera_set_balance_property (priv->webcam, "saturation", saturation);
+    cheese_camera_set_balance_property (priv->webcam, "hue", hue);
+    priv->state = CHEESE_WIDGET_STATE_READY;
+    g_object_notify (G_OBJECT (widget), "state");
     cheese_camera_play (priv->webcam);
     gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), WEBCAM_PAGE);
   }
@@ -352,7 +353,6 @@ cheese_widget_realize (GtkWidget *widget)
 {
   GdkWindow           *window;
   CheeseWidgetPrivate *priv  = CHEESE_WIDGET_GET_PRIVATE (widget);
-  GError              *error = NULL;
 
   GTK_WIDGET_CLASS (cheese_widget_parent_class)->realize (widget);
 
@@ -371,10 +371,9 @@ cheese_widget_realize (GtkWidget *widget)
   gtk_widget_set_app_paintable (priv->screen, TRUE);
   gtk_widget_set_double_buffered (priv->screen, FALSE);
 
-  if (!g_thread_create ((GThreadFunc) setup_camera, widget, FALSE, &error))
+  if (!g_thread_create ((GThreadFunc) setup_camera, widget, FALSE, &priv->error))
   {
-    g_warning ("Failed to create setup thread: %s\n", error->message);
-    g_error_free (error);
+    g_warning ("Failed to create setup thread: %s", priv->error->message);
     goto error;
   }
 
@@ -386,9 +385,9 @@ cheese_widget_realize (GtkWidget *widget)
 
 error:
   gtk_spinner_stop (GTK_SPINNER (priv->spinner));
+  priv->state = CHEESE_WIDGET_STATE_ERROR;
+  g_object_notify (G_OBJECT (widget), "state");
   cheese_widget_set_problem_page (CHEESE_WIDGET (widget), "error");
-  g_signal_emit (widget, widget_signals[ERROR_SIGNAL], 0,
-                 _("Camera setup failed"));
 }
 
 static void
@@ -400,39 +399,26 @@ cheese_widget_class_init (CheeseWidgetClass *klass)
   object_class->finalize = cheese_widget_finalize;
 #if 0
   object_class->set_property = cheese_widget_set_property;
-  object_class->get_property = cheese_widget_get_property;
 #endif
+  object_class->get_property = cheese_widget_get_property;
   widget_class->realize = cheese_widget_realize;
 
   /**
-   * CheeseWidget::ready:
+   * CheeseWidget:state:
    *
-   * @is_ready: Whether the camera is ready for use by the widget.
+   * Current state of the widget.
    *
-   * The ::ready signal is emitted when the camera is ready to be
-   * used by the widget and other applications.
+   * Connect to notify::state signal to get notified about state
+   * changes. Useful to update other widgets sensitiveness when the
+   * camera is ready or to handle errors if camera setup fails.
    */
-  widget_signals[READY_SIGNAL] = g_signal_new ("ready", G_OBJECT_CLASS_TYPE (klass),
-                                               G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-                                               G_STRUCT_OFFSET (CheeseWidgetClass, ready),
-                                               NULL, NULL,
-                                               g_cclosure_marshal_VOID__BOOLEAN,
-                                               G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
-
-  /**
-   * CheeseWidget::error:
-   *
-   * @error: The error message.
-   *
-   * The ::error signal is emitted when the widget cannot access
-   * the camera.
-   */
-  widget_signals[ERROR_SIGNAL] = g_signal_new ("error", G_OBJECT_CLASS_TYPE (klass),
-                                               G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-                                               G_STRUCT_OFFSET (CheeseWidgetClass, error),
-                                               NULL, NULL,
-                                               g_cclosure_marshal_VOID__STRING,
-                                               G_TYPE_NONE, 1, G_TYPE_STRING);
+  g_object_class_install_property (object_class, PROP_STATE,
+                                   g_param_spec_enum ("state",
+                                                      NULL,
+                                                      NULL,
+                                                      CHEESE_TYPE_WIDGET_STATE,
+                                                      CHEESE_WIDGET_STATE_NONE,
+                                                      G_PARAM_READABLE));
 
   g_type_class_add_private (klass, sizeof (CheeseWidgetPrivate));
 }
@@ -486,6 +472,30 @@ cheese_widget_get_video_area (CheeseWidget *widget)
   return priv->screen;
 }
 
+/**
+ * cheese_widget_get_error:
+ * @widget: a #CheeseWidget
+ * @error: return location for the error
+ *
+ * Listen for notify::state signals and call this when the current state is %CHEESE_WIDGET_STATE_ERROR.
+ *
+ * The returned #GError will contain more details on what went wrong.
+ **/
+
+void
+cheese_widget_get_error (CheeseWidget *widget, GError **error)
+{
+  CheeseWidgetPrivate *priv;
+
+  g_return_if_fail (CHEESE_WIDGET (widget));
+
+  priv = CHEESE_WIDGET_GET_PRIVATE (widget);
+
+  g_propagate_error (error, priv->error);
+
+  priv->error = NULL;
+}
+
 /*
  * vim: sw=2 ts=8 cindent noai bs=2
  */
