@@ -371,12 +371,14 @@ cheese_window_fullscreen_leave_notify_cb (GtkWidget        *widget,
 void
 cheese_window_toggle_wide_mode (GtkWidget *widget, CheeseWindow *cheese_window)
 {
+  GtkAllocation allocation;
   CheeseWindowPrivate *priv = CHEESE_WINDOW_GET_PRIVATE (cheese_window);
   gboolean toggled = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (widget));
 
+  gtk_widget_get_allocation (GTK_WIDGET (priv->thewidget), &allocation);
   gtk_widget_set_size_request (priv->thewidget,
-                               GTK_WIDGET (priv->thewidget)->allocation.width,
-                               GTK_WIDGET (priv->thewidget)->allocation.height);
+                               allocation.width,
+                               allocation.height);
 
   /* set a single column in wide mode */
   gtk_icon_view_set_columns (GTK_ICON_VIEW (priv->thumb_view), toggled ? 1 : G_MAXINT);
@@ -1213,6 +1215,7 @@ on_widget_error (CheeseWidget        *widget,
 
   /* FIXME: hotplug new devices and hide the info bar */
   gtk_action_group_set_sensitive (priv->actions_prefs, FALSE);
+  gtk_action_group_set_sensitive (priv->actions_photo, FALSE);
   cheese_no_camera_set_info_bar_text_and_icon (GTK_INFO_BAR (priv->info_bar),
                                                "gtk-dialog-error",
                                                error->message,
