@@ -20,7 +20,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <cheese-config.h>
+  #include <cheese-config.h>
 #endif
 
 #include "eog-thumb-nav.h"
@@ -32,14 +32,14 @@
 #include <gtk/gtk.h>
 #include <string.h>
 
-#define EOG_THUMB_NAV_GET_PRIVATE(object)                               \
+#define EOG_THUMB_NAV_GET_PRIVATE(object) \
   (G_TYPE_INSTANCE_GET_PRIVATE ((object), EOG_TYPE_THUMB_NAV, EogThumbNavPrivate))
 
 G_DEFINE_TYPE (EogThumbNav, eog_thumb_nav, GTK_TYPE_HBOX);
 
-#define EOG_THUMB_NAV_SCROLL_INC      20
-#define EOG_THUMB_NAV_SCROLL_MOVE     20
-#define EOG_THUMB_NAV_SCROLL_TIMEOUT  20
+#define EOG_THUMB_NAV_SCROLL_INC     20
+#define EOG_THUMB_NAV_SCROLL_MOVE    20
+#define EOG_THUMB_NAV_SCROLL_TIMEOUT 20
 
 enum
 {
@@ -48,54 +48,57 @@ enum
   PROP_MODE
 };
 
-struct _EogThumbNavPrivate {
-  gboolean          show_buttons;
-  gboolean          vertical;
-  gboolean          scroll_dir;
-  gint              scroll_pos;
-  gint              scroll_id;
+struct _EogThumbNavPrivate
+{
+  gboolean show_buttons;
+  gboolean vertical;
+  gboolean scroll_dir;
+  gint scroll_pos;
+  gint scroll_id;
 
-  GtkWidget        *button_up;
-  GtkWidget        *button_down;
-  GtkWidget        *button_left;
-  GtkWidget        *button_right;
-  GtkWidget        *sw;
-  GtkWidget        *thumbview;
-  GtkWidget        *vbox;
-  GtkAdjustment    *hadj;
-  GtkAdjustment    *vadj;
-  GtkAdjustment    *adj;
+  GtkWidget *button_up;
+  GtkWidget *button_down;
+  GtkWidget *button_left;
+  GtkWidget *button_right;
+  GtkWidget *sw;
+  GtkWidget *thumbview;
+  GtkWidget *vbox;
+  GtkAdjustment *hadj;
+  GtkAdjustment *vadj;
+  GtkAdjustment *adj;
 };
 
 static gboolean
 eog_thumb_nav_scroll_event (GtkWidget *widget, GdkEventScroll *event, gpointer user_data)
 {
   EogThumbNav *nav = EOG_THUMB_NAV (user_data);
-  gint inc = EOG_THUMB_NAV_SCROLL_INC * 3;
-  gdouble value, upper, page_size;
+  gint         inc = EOG_THUMB_NAV_SCROLL_INC * 3;
+  gdouble      value, upper, page_size;
 
   nav->priv->adj = nav->priv->vertical ? nav->priv->vadj : nav->priv->hadj;
 
-  switch (event->direction) {
-  case GDK_SCROLL_UP:
-  case GDK_SCROLL_LEFT:
-    inc *= -1;
-    break;
+  switch (event->direction)
+  {
+    case GDK_SCROLL_UP:
+    case GDK_SCROLL_LEFT:
+      inc *= -1;
+      break;
 
-  case GDK_SCROLL_DOWN:
-  case GDK_SCROLL_RIGHT:
-    break;
+    case GDK_SCROLL_DOWN:
+    case GDK_SCROLL_RIGHT:
+      break;
 
-  default:
-    g_assert_not_reached ();
-    return FALSE;
+    default:
+      g_assert_not_reached ();
+      return FALSE;
   }
 
   value = gtk_adjustment_get_value (nav->priv->adj);
   if (inc < 0)
     gtk_adjustment_set_value (nav->priv->adj, MAX (0, value + inc));
-  else {
-    upper = gtk_adjustment_get_upper (nav->priv->adj);
+  else
+  {
+    upper     = gtk_adjustment_get_upper (nav->priv->adj);
     page_size = gtk_adjustment_get_page_size (nav->priv->adj);
     gtk_adjustment_set_value (nav->priv->adj, MIN (upper - page_size, value + inc));
   }
@@ -108,14 +111,14 @@ eog_thumb_nav_scroll_event (GtkWidget *widget, GdkEventScroll *event, gpointer u
 static void
 eog_thumb_nav_vadj_changed (GtkAdjustment *vadj, gpointer user_data)
 {
-  EogThumbNav *nav;
+  EogThumbNav        *nav;
   EogThumbNavPrivate *priv;
-  gboolean ltr;
-  gdouble value, upper, page_size;
+  gboolean            ltr;
+  gdouble             value, upper, page_size;
 
-  nav = EOG_THUMB_NAV (user_data);
+  nav  = EOG_THUMB_NAV (user_data);
   priv = EOG_THUMB_NAV_GET_PRIVATE (nav);
-  ltr = gtk_widget_get_direction (priv->sw) == GTK_TEXT_DIR_LTR;
+  ltr  = gtk_widget_get_direction (priv->sw) == GTK_TEXT_DIR_LTR;
 
   g_object_get (vadj,
                 "value", &value,
@@ -131,14 +134,14 @@ eog_thumb_nav_vadj_changed (GtkAdjustment *vadj, gpointer user_data)
 static void
 eog_thumb_nav_hadj_changed (GtkAdjustment *hadj, gpointer user_data)
 {
-  EogThumbNav *nav;
+  EogThumbNav        *nav;
   EogThumbNavPrivate *priv;
-  gboolean ltr;
-  gdouble value, upper, page_size;
+  gboolean            ltr;
+  gdouble             value, upper, page_size;
 
-  nav = EOG_THUMB_NAV (user_data);
+  nav  = EOG_THUMB_NAV (user_data);
   priv = EOG_THUMB_NAV_GET_PRIVATE (nav);
-  ltr = gtk_widget_get_direction (priv->sw) == GTK_TEXT_DIR_LTR;
+  ltr  = gtk_widget_get_direction (priv->sw) == GTK_TEXT_DIR_LTR;
 
   g_object_get (hadj,
                 "value", &value,
@@ -153,14 +156,14 @@ eog_thumb_nav_hadj_changed (GtkAdjustment *hadj, gpointer user_data)
 static void
 eog_thumb_nav_vadj_value_changed (GtkAdjustment *vadj, gpointer user_data)
 {
-  EogThumbNav *nav;
+  EogThumbNav        *nav;
   EogThumbNavPrivate *priv;
-  gboolean ltr;
-  gdouble value, upper, page_size;
+  gboolean            ltr;
+  gdouble             value, upper, page_size;
 
-  nav = EOG_THUMB_NAV (user_data);
+  nav  = EOG_THUMB_NAV (user_data);
   priv = EOG_THUMB_NAV_GET_PRIVATE (nav);
-  ltr = gtk_widget_get_direction (priv->sw) == GTK_TEXT_DIR_LTR;
+  ltr  = gtk_widget_get_direction (priv->sw) == GTK_TEXT_DIR_LTR;
 
   g_object_get (vadj,
                 "value", &value,
@@ -177,14 +180,14 @@ eog_thumb_nav_vadj_value_changed (GtkAdjustment *vadj, gpointer user_data)
 static void
 eog_thumb_nav_hadj_value_changed (GtkAdjustment *hadj, gpointer user_data)
 {
-  EogThumbNav *nav;
+  EogThumbNav        *nav;
   EogThumbNavPrivate *priv;
-  gboolean ltr;
-  gdouble value, upper, page_size;
+  gboolean            ltr;
+  gdouble             value, upper, page_size;
 
-  nav = EOG_THUMB_NAV (user_data);
+  nav  = EOG_THUMB_NAV (user_data);
   priv = EOG_THUMB_NAV_GET_PRIVATE (nav);
-  ltr = gtk_widget_get_direction (priv->sw) == GTK_TEXT_DIR_LTR;
+  ltr  = gtk_widget_get_direction (priv->sw) == GTK_TEXT_DIR_LTR;
 
   g_object_get (hadj,
                 "value", &value,
@@ -202,8 +205,8 @@ static gboolean
 eog_thumb_nav_scroll_step (gpointer user_data)
 {
   EogThumbNav *nav = EOG_THUMB_NAV (user_data);
-  gint delta;
-  gdouble value, upper, page_size;
+  gint         delta;
+  gdouble      value, upper, page_size;
 
   if (nav->priv->scroll_pos < 10)
     delta = EOG_THUMB_NAV_SCROLL_INC;
@@ -224,11 +227,14 @@ eog_thumb_nav_scroll_step (gpointer user_data)
                 NULL);
 
   if ((gint) (value + (gdouble) delta) >= 0 &&
-      (gint) (value + (gdouble) delta) <= upper - page_size) {
+      (gint) (value + (gdouble) delta) <= upper - page_size)
+  {
     gtk_adjustment_set_value (nav->priv->adj, value + (gdouble) delta);
     nav->priv->scroll_pos++;
     gtk_adjustment_value_changed (nav->priv->adj);
-  } else {
+  }
+  else
+  {
     if (delta > 0)
       gtk_adjustment_set_value (nav->priv->adj, upper - page_size);
     else
@@ -253,9 +259,11 @@ eog_thumb_nav_button_clicked (GtkButton *button, EogThumbNav *nav)
       (GTK_WIDGET (button) == nav->priv->button_left))
   {
     nav->priv->scroll_dir = gtk_widget_get_direction (GTK_WIDGET (button)) == GTK_TEXT_DIR_LTR ?
-      GTK_WIDGET (button) == nav->priv->button_right :
-      GTK_WIDGET (button) == nav->priv->button_left;
-  } else {
+                            GTK_WIDGET (button) == nav->priv->button_right :
+                            GTK_WIDGET (button) == nav->priv->button_left;
+  }
+  else
+  {
     nav->priv->scroll_dir = (GTK_WIDGET (button) == nav->priv->button_down);
   }
 
@@ -268,14 +276,15 @@ eog_thumb_nav_button_clicked (GtkButton *button, EogThumbNav *nav)
 static void
 eog_thumb_nav_start_scroll (GtkButton *button, EogThumbNav *nav)
 {
-
   if ((GTK_WIDGET (button) == nav->priv->button_right) ||
       (GTK_WIDGET (button) == nav->priv->button_left))
   {
     nav->priv->scroll_dir = gtk_widget_get_direction (GTK_WIDGET (button)) == GTK_TEXT_DIR_LTR ?
-      GTK_WIDGET (button) == nav->priv->button_right :
-      GTK_WIDGET (button) == nav->priv->button_left;
-  } else {
+                            GTK_WIDGET (button) == nav->priv->button_right :
+                            GTK_WIDGET (button) == nav->priv->button_left;
+  }
+  else
+  {
     nav->priv->scroll_dir = (GTK_WIDGET (button) == nav->priv->button_down);
   }
 
@@ -290,9 +299,10 @@ eog_thumb_nav_start_scroll (GtkButton *button, EogThumbNav *nav)
 static void
 eog_thumb_nav_stop_scroll (GtkButton *button, EogThumbNav *nav)
 {
-  if (nav->priv->scroll_id > 0) {
+  if (nav->priv->scroll_id > 0)
+  {
     g_source_remove (nav->priv->scroll_id);
-    nav->priv->scroll_id = 0;
+    nav->priv->scroll_id  = 0;
     nav->priv->scroll_pos = 0;
   }
 }
@@ -307,14 +317,14 @@ eog_thumb_nav_get_property (GObject    *object,
 
   switch (property_id)
   {
-  case PROP_SHOW_BUTTONS:
-    g_value_set_boolean (value,
-                         eog_thumb_nav_get_show_buttons (nav));
-    break;
+    case PROP_SHOW_BUTTONS:
+      g_value_set_boolean (value,
+                           eog_thumb_nav_get_show_buttons (nav));
+      break;
 
-  case PROP_THUMB_VIEW:
-    g_value_set_object (value, nav->priv->thumbview);
-    break;
+    case PROP_THUMB_VIEW:
+      g_value_set_object (value, nav->priv->thumbview);
+      break;
   }
 }
 
@@ -328,40 +338,41 @@ eog_thumb_nav_set_property (GObject      *object,
 
   switch (property_id)
   {
-  case PROP_SHOW_BUTTONS:
-    eog_thumb_nav_set_show_buttons (nav,
-                                    g_value_get_boolean (value));
-    break;
+    case PROP_SHOW_BUTTONS:
+      eog_thumb_nav_set_show_buttons (nav,
+                                      g_value_get_boolean (value));
+      break;
 
-  case PROP_THUMB_VIEW:
-    nav->priv->thumbview =
-      GTK_WIDGET (g_value_get_object (value));
-    break;
+    case PROP_THUMB_VIEW:
+      nav->priv->thumbview =
+        GTK_WIDGET (g_value_get_object (value));
+      break;
   }
 }
 
 static GObject *
-eog_thumb_nav_constructor (GType type,
-                           guint n_construct_properties,
+eog_thumb_nav_constructor (GType                  type,
+                           guint                  n_construct_properties,
                            GObjectConstructParam *construct_params)
 {
-  GObject *object;
-  EogThumbNav *nav;
+  GObject            *object;
+  EogThumbNav        *nav;
   EogThumbNavPrivate *priv;
 
   object = G_OBJECT_CLASS (eog_thumb_nav_parent_class)->constructor
-    (type, n_construct_properties, construct_params);
+             (type, n_construct_properties, construct_params);
 
-  nav = EOG_THUMB_NAV (object);
+  nav  = EOG_THUMB_NAV (object);
   priv = EOG_THUMB_NAV_GET_PRIVATE (object);
 
-  if (priv->thumbview != NULL) {
+  if (priv->thumbview != NULL)
+  {
     gtk_container_add (GTK_CONTAINER (priv->sw), priv->thumbview);
     gtk_widget_show_all (priv->sw);
   }
 
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (priv->sw),
-                                  GTK_POLICY_NEVER,
+                                  GTK_POLICY_AUTOMATIC,
                                   GTK_POLICY_NEVER);
 
   return object;
@@ -401,14 +412,14 @@ static void
 eog_thumb_nav_init (EogThumbNav *nav)
 {
   EogThumbNavPrivate *priv;
-  GtkWidget *arrow;
+  GtkWidget          *arrow;
 
   nav->priv = EOG_THUMB_NAV_GET_PRIVATE (nav);
 
   priv = nav->priv;
 
   priv->show_buttons = TRUE;
-  priv->vertical = FALSE;
+  priv->vertical     = FALSE;
 
   priv->button_left = gtk_button_new ();
   gtk_button_set_relief (GTK_BUTTON (priv->button_left), GTK_RELIEF_NONE);
@@ -588,10 +599,10 @@ eog_thumb_nav_init (EogThumbNav *nav)
  * Returns: a new #EogThumbNav object.
  **/
 GtkWidget *
-eog_thumb_nav_new (GtkWidget       *thumbview,
-                   gboolean         show_buttons)
+eog_thumb_nav_new (GtkWidget *thumbview,
+                   gboolean   show_buttons)
 {
-  EogThumbNav *nav;
+  EogThumbNav        *nav;
   EogThumbNavPrivate *priv;
 
   nav = g_object_new (EOG_TYPE_THUMB_NAV,
@@ -635,26 +646,30 @@ void
 eog_thumb_nav_set_show_buttons (EogThumbNav *nav, gboolean show_buttons)
 {
   g_return_if_fail (EOG_IS_THUMB_NAV (nav));
-  g_return_if_fail (nav->priv->button_left  != NULL);
+  g_return_if_fail (nav->priv->button_left != NULL);
   g_return_if_fail (nav->priv->button_right != NULL);
 
   nav->priv->show_buttons = show_buttons;
 
-  if (show_buttons) {
+  if (show_buttons)
+  {
     gtk_widget_show_all (nav->priv->button_left);
     gtk_widget_show_all (nav->priv->button_right);
-  } else {
+  }
+  else
+  {
     gtk_widget_hide_all (nav->priv->button_left);
     gtk_widget_hide_all (nav->priv->button_right);
   }
 }
 
 void
-eog_thumb_nav_set_policy (EogThumbNav *nav,
+eog_thumb_nav_set_policy (EogThumbNav  *nav,
                           GtkPolicyType hscrollbar_policy,
                           GtkPolicyType vscrollbar_policy)
 {
   EogThumbNavPrivate *priv = EOG_THUMB_NAV_GET_PRIVATE (nav);
+
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (priv->sw),
                                   hscrollbar_policy,
                                   vscrollbar_policy);
@@ -664,6 +679,7 @@ gboolean
 eog_thumb_nav_is_vertical (EogThumbNav *nav)
 {
   EogThumbNavPrivate *priv = EOG_THUMB_NAV_GET_PRIVATE (nav);
+
   return priv->vertical;
 }
 
@@ -673,7 +689,7 @@ eog_thumb_nav_set_vertical (EogThumbNav *nav, gboolean vertical)
   EogThumbNavPrivate *priv = EOG_THUMB_NAV_GET_PRIVATE (nav);
 
   g_return_if_fail (EOG_IS_THUMB_NAV (nav));
-  g_return_if_fail (priv->button_left  != NULL);
+  g_return_if_fail (priv->button_left != NULL);
   g_return_if_fail (priv->button_right != NULL);
   g_return_if_fail (priv->vbox != NULL);
   g_return_if_fail (priv->sw != NULL);
@@ -682,7 +698,8 @@ eog_thumb_nav_set_vertical (EogThumbNav *nav, gboolean vertical)
 
   /* show/hide doesn't work because of a mandatory show_all in cheese-window */
 
-  if (vertical) {
+  if (vertical)
+  {
     g_return_if_fail (!gtk_widget_get_parent (priv->button_up));
     g_return_if_fail (!gtk_widget_get_parent (priv->button_down));
     g_return_if_fail (gtk_widget_get_parent (priv->button_left));
@@ -699,8 +716,14 @@ eog_thumb_nav_set_vertical (EogThumbNav *nav, gboolean vertical)
     g_object_ref (priv->button_right);
     gtk_container_remove (GTK_CONTAINER (nav), priv->button_right);
     gtk_adjustment_value_changed (priv->vadj);
+
+    eog_thumb_nav_set_policy (nav,
+                              GTK_POLICY_NEVER,
+                              GTK_POLICY_AUTOMATIC);
     priv->vertical = TRUE;
-  } else {
+  }
+  else
+  {
     g_return_if_fail (!gtk_widget_get_parent (priv->button_left));
     g_return_if_fail (!gtk_widget_get_parent (priv->button_right));
     g_return_if_fail (gtk_widget_get_parent (priv->button_up));
@@ -717,8 +740,11 @@ eog_thumb_nav_set_vertical (EogThumbNav *nav, gboolean vertical)
     g_object_ref (priv->button_down);
     gtk_container_remove (GTK_CONTAINER (priv->vbox), priv->button_down);
     gtk_adjustment_value_changed (priv->hadj);
+
+    eog_thumb_nav_set_policy (nav,
+                              GTK_POLICY_AUTOMATIC,
+                              GTK_POLICY_NEVER);
     priv->vertical = FALSE;
   }
   gtk_widget_show_all (GTK_WIDGET (nav));
 }
-
